@@ -15,6 +15,10 @@ class WebElementWrapper(object):
         self.current_web_element_list: [List[WebElement]] = None
 
     def submit(self) -> None:
+        """
+        current web element submit
+        :return: None
+        """
         try:
             self.current_web_element.submit()
             record_action_to_list("Web element submit", None, None)
@@ -23,6 +27,10 @@ class WebElementWrapper(object):
             record_action_to_list("Web element submit", None, error)
 
     def clear(self) -> None:
+        """
+        current web element clear
+        :return: None
+        """
         try:
             self.current_web_element.clear()
             record_action_to_list("Web element clear", None, None)
@@ -30,7 +38,11 @@ class WebElementWrapper(object):
             print(repr(error), file=stderr)
             record_action_to_list("Web element clear", None, error)
 
-    def get_property(self, name) -> str:
+    def get_property(self, name: str) -> str:
+        """
+        :param name: name of property
+        :return: property value as str
+        """
         param = locals()
         try:
             record_action_to_list("Web element get_property", param, None)
@@ -39,7 +51,11 @@ class WebElementWrapper(object):
             print(repr(error), file=stderr)
             record_action_to_list("Web element get_property", param, error)
 
-    def get_dom_attribute(self, name) -> str:
+    def get_dom_attribute(self, name: str) -> str:
+        """
+        :param name: name of dom
+        :return: dom attribute value as str
+        """
         param = locals()
         try:
             record_action_to_list("Web element get_dom_attribute", param, None)
@@ -48,7 +64,11 @@ class WebElementWrapper(object):
             print(repr(error), file=stderr)
             record_action_to_list("Web element get_dom_attribute", param, error)
 
-    def get_attribute(self, name) -> str:
+    def get_attribute(self, name: str) -> str:
+        """
+        :param name: name of web element
+        :return:web element attribute value as str
+        """
         param = locals()
         try:
             record_action_to_list("Web element get_attribute", param, None)
@@ -58,6 +78,10 @@ class WebElementWrapper(object):
             record_action_to_list("Web element get_attribute", param, error)
 
     def is_selected(self) -> bool:
+        """
+        check current web element is selected or not
+        :return: True or False
+        """
         try:
             record_action_to_list("Web element is_selected", None, None)
             return self.current_web_element.is_selected()
@@ -66,6 +90,10 @@ class WebElementWrapper(object):
             record_action_to_list("Web element is_selected", None, error)
 
     def is_enabled(self) -> bool:
+        """
+        check current web element is enable or not
+        :return: True or False
+        """
         try:
             record_action_to_list("Web element is_enabled", None, None)
             return self.current_web_element.is_enabled()
@@ -73,7 +101,12 @@ class WebElementWrapper(object):
             print(repr(error), file=stderr)
             record_action_to_list("Web element is_enabled", None, error)
 
-    def input_to_element(self, input_value) -> None:
+    def input_to_element(self, input_value: str) -> None:
+        """
+        input value to current web element
+        :param input_value: what value we want to input to current web element
+        :return: None
+        """
         param = locals()
         try:
             self.current_web_element.send_keys(input_value)
@@ -83,6 +116,10 @@ class WebElementWrapper(object):
             record_action_to_list("Web element input_to_element", param, error)
 
     def click_element(self) -> None:
+        """
+        click current web element
+        :return: None
+        """
         try:
             self.current_web_element.click()
             record_action_to_list("Web element click_element", None, None)
@@ -91,6 +128,10 @@ class WebElementWrapper(object):
             record_action_to_list("Web element click_element", None, error)
 
     def is_displayed(self) -> bool:
+        """
+        check current web element is displayed or not
+        :return: True or False
+        """
         try:
             record_action_to_list("Web element is_displayed", None, None)
             return self.current_web_element.is_displayed()
@@ -98,7 +139,11 @@ class WebElementWrapper(object):
             print(repr(error), file=stderr)
             record_action_to_list("Web element is_displayed", None, error)
 
-    def value_of_css_property(self, property_name) -> str:
+    def value_of_css_property(self, property_name: str) -> str:
+        """
+        :param property_name: name of property
+        :return: css property value as str
+        """
         param = locals()
         try:
             record_action_to_list("Web element value_of_css_property", param, None)
@@ -107,17 +152,25 @@ class WebElementWrapper(object):
             print(repr(error), file=stderr)
             record_action_to_list("Web element value_of_css_property", param, error)
 
-    def screenshot(self, filename) -> bool:
+    def screenshot(self, filename: str) -> bool:
+        """
+        :param filename: full file name not need .png extension
+        :return: Save True or not
+        """
         param = locals()
         try:
             record_action_to_list("Web element screenshot", param, None)
-            return self.current_web_element.screenshot(filename)
+            return self.current_web_element.screenshot(filename + ".png")
         except Exception as error:
             print(repr(error), file=stderr)
             record_action_to_list("Web element screenshot", param, error)
 
     # Web element wrapper add function
     def change_web_element(self, element_index: int) -> None:
+        """
+        :param element_index: change to web element index
+        :return: web element list [element_index]
+        """
         param = locals()
         try:
             self.current_web_element = self.current_web_element_list[element_index]
@@ -127,6 +180,10 @@ class WebElementWrapper(object):
             record_action_to_list("Web element change_web_element", param, error)
 
     def check_current_web_element(self, check_dict: dict) -> None:
+        """
+        :param check_dict: check web element dict {name: should be value}
+        :return: None
+        """
         param = locals()
         try:
             check_web_element(self.current_web_element, check_dict)
@@ -136,6 +193,10 @@ class WebElementWrapper(object):
             record_action_to_list("Web element check_current_web_element", param, error)
 
     def get_select(self) -> Select:
+        """
+        get Select(current web element)
+        :return: Select(current web element)
+        """
         try:
             record_action_to_list("Web element get_select", None, None)
             return Select(self.current_web_element)
@@ -144,4 +205,5 @@ class WebElementWrapper(object):
             record_action_to_list("Web element get_select", None, error)
 
 
+# use this wrapper to use web element
 web_element_wrapper = WebElementWrapper()
