@@ -1,11 +1,12 @@
 from selenium.webdriver.remote.webdriver import WebDriver
 from selenium.webdriver.remote.webelement import WebElement
 
-from je_web_runner.utils.exception.exceptions import AssertException
+from je_web_runner.utils.exception.exceptions import WebRunnerAssertException
 
 
 def _make_webdriver_check_dict(webdriver_to_check: WebDriver) -> dict:
     """
+    use to check webdriver current info
     :param webdriver_to_check: what webdriver we want to check
     :return: webdriver detail dict
     """
@@ -32,6 +33,7 @@ def _make_webdriver_check_dict(webdriver_to_check: WebDriver) -> dict:
 
 def _make_web_element_check_dict(web_element_to_check: WebElement) -> dict:
     """
+    use to check web element current info
     :param web_element_to_check: what web element we want to check
     :return: web element detail dict
     """
@@ -58,7 +60,7 @@ def check_value(check_dict: dict, result_check_dict: dict) -> None:
     """
     for key, value in result_check_dict.items():
         if check_dict.get(key) != value:
-            raise AssertException(
+            raise WebRunnerAssertException(
                 "value should be {right_value} but value was {wrong_value}".format(
                     right_value=value, wrong_value=check_dict.get(key)
                 )
